* Output options: all can be turned on/off by adding/ removing the NO;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX NOfmterr;
* Remove default title, turn on new HTML graphics;
  TITLE; ODS GRAPHICS ON; 

* Lines that start with * are COMMENTS (notes to yourself);
* Each SAS command (that starts with a BLUE word) must end with a semi-colon;
* Data transformations (e.g., making new variables) must occur within 
    a DATA+SET data step and must end with a semi-colon;
* USE COLORS TO HELP YOU! Comments are GREEN, SAS system commands are BLUE,
    Variables and file names are BLACK, and if you see RED, something is wrong, 
    Libraries and Labels are PURPLE are case-sensitive and space-sensitive;

* To execute select code, highlight it -- then click the run icon above,
    or use keyboard short-cut F3 in Windows;

***********************************************************************************;
*******      FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION        *******;
***********************************************************************************;

* Paste in the folder address where "GSS_Example.xlsx" is saved after = before ;
%LET filesave= C:\Dropbox\22SP_PSQF6243\PSQF6243_Example1;
* Using UIowa virtual desktop instead;
*%LET filesave= \\Client\C:\Dropbox\22SP_PSQF6243\PSQF6243_Example1;

* We can then refer to the filesave place by putting & in front and . behind it;

* IMPORT GSS_Example.xlsx data using filesave reference and exact file name;
* from the Excel workbook in DATAFILE= location from SHEET= ;
* New SAS file is in "work" library place with name "Example1";
* "GETNAMES" reads in the first row as variable names;
* DBMS=XLSX (can also use EXCEL or XLS for .xls files);
PROC IMPORT DATAFILE="&filesave.\GSS_Example.xlsx" 
            OUT=work.Example1 DBMS=XLSX REPLACE; 
     SHEET="GSS_Example"; 
     GETNAMES=YES; 
RUN;

* Create formats: set of value labels for categorical variables;
PROC FORMAT;
     VALUE Fmarital 1="1.Married" 2="2.Widowed" 3="3.Divorced"
                       4="4.Separated" 5="5.Never";
	VALUE Fhappy   1="1.Unhappy" 2="2.Neither" 3="3.Fairly" 
	                  4="4.Very" 5="5.Completely";
RUN;

* DATA = create new dataset, SET = from OLD dataset;
* So DATA + SET means "save as itself" after these actions;
* All data transformations must happen inside a DATA+SET+RUN combo;
DATA work.Example1; SET work.Example1;
* Label variables used below (add descriptive titles to each variable);
* Note there is one semi-colon at the END of all labels;
* LABEL name=    "name: Descriptive Variable Label";
  LABEL marital= "marital: 5-Category Marital Status"
	   happy=   "happy: 5-Category Happy Rating"
        income=  "income: Annual Income in 1000s";
* Apply value labels created above: name Format.;
  FORMAT marital Fmarital. happy Fhappy.; 
RUN;
* Now datset work.Example1 is ready to use; 


***********************************************************************************;
*******              BEGIN EXAMPLE 1 UNIVARIATE STATISTICS                  *******;
***********************************************************************************;

* TITLE prints in output, to remove, just type TITLE again;

* PROC FREQ prints frequency and percentage tables for categorical variables;
* TABLE = variables / mention missing values and make percentage barchart;
TITLE "SAS Frequency Table and Plot for Categorical Variable marital";
PROC FREQ DATA=work.Example1;               
     TABLE marital / MISSING PLOTS=FREQPLOT(TYPE=BAR SCALE=PERCENT);  
RUN; TITLE; 

* PROC UNIVARIATE prints ALL descriptive statistics for quantitative variables;
* VAR = variables, histogram midpoints= start to end by increment;
TITLE "SAS Descriptive Statistics and Histogram for Quantitative Variable income";
PROC UNIVARIATE DATA=work.Example1;
     VAR income;
     HISTOGRAM income / MIDPOINTS=0 TO 70 BY 5;
RUN; TITLE;

* PROC MEANS prints fewer descriptive statistics for quantitative variables; 
* NDEC= controls number of decimal places, VAR lists variables;
TITLE "SAS Descriptive Statistics for Quantitative Variable income";
PROC MEANS DATA=work.Example1 NDEC=3 N MEAN STDDEV VAR MIN MAX;
     VAR income;
RUN; TITLE;

* One more example: exploring an ordinal variable;
TITLE "SAS Descriptive Statistics and Histogram for Ordinal Variable happy";
PROC UNIVARIATE DATA=work.Example1;
     VAR happy;
     HISTOGRAM happy / MIDPOINTS=1 TO 5 BY 1;
RUN; TITLE;


***********************************************************************************;
*******              BONUS: CODE TO SAVE OUTPUT AS NEEDED                   *******;
***********************************************************************************;

* Open output directory to save results and plots to;
ODS RTF FILE="&filesave.\Example1_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

* Commands to generate output to be saved go here;


* Close output;
ODS RTF CLOSE;
 
